@@ -3,11 +3,12 @@ package Sort::Sub::by_example;
 use 5.010001;
 use strict;
 use warnings;
+use Log::ger;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2025-01-12'; # DATE
 our $DIST = 'Sort-Sub-by_example'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 sub meta {
     return {
@@ -34,6 +35,8 @@ sub gen_sorter {
     $example = [map {lc} @$example] if $is_ci;
     $example = [reverse @$example] if $is_reverse;
 
+    log_trace "example=%s", $example;
+
     my $cmp = Sort::ByExample->cmp($example);
     #use Data::Dmp; dd $cmp
 }
@@ -53,7 +56,7 @@ Sort::Sub::by_example - Sort by example
 
 =head1 VERSION
 
-This document describes version 0.004 of Sort::Sub::by_example (from Perl distribution Sort-Sub-by_example), released on 2025-01-12.
+This document describes version 0.005 of Sort::Sub::by_example (from Perl distribution Sort-Sub-by_example), released on 2025-01-12.
 
 =head1 SYNOPSIS
 
